Launch notes
- Launch GitLab instance
- TODO: configure SSL
- Set root password through web interface
- Configure GitHub signon integration: https://docs.gitlab.com/ee/integration/github.html
- Log in as a GitHub user (it will be blocked)
- Log in as root and unblock the user
- Create EKS cluster
- Launch nodes into EKS cluster: https://docs.aws.amazon.com/eks/latest/userguide/launch-workers.html
- Configure GitLab EKS integration: https://docs.gitlab.com/ee/user/project/clusters/eks_and_gitlab/index.html
